@@ -66,7 +66,7 @@ class BaseMLRegressor(object):
         # Obtain parameters if not provided
         if self.param_grid is None:
             self.param_grid = get_param_grid_from_estimator(estimator=self.estimator)
-
+            
         # Set param_grid values to list if not already list
         self.param_grid = {k: list(set(v)) if isinstance(v, list) else v.tolist() if isinstance(v, np.ndarray) else [v] for k, v in self.param_grid.items()}
 
@@ -170,7 +170,10 @@ class BaseMLRegressor(object):
         self.estimator_cv.fit(X=X,y=y,sample_weight=sample_weight)
         
         # Mean cross-validated score of the best_estimator
-        self.best_mean_cv_score_ = self.estimator_cv.best_score_
+        if hasattr(self.estimator_cv, "best_score_"):     
+            self.best_mean_cv_score_ = self.estimator_cv.best_score_
+        else:
+            self.best_mean_cv_score_ = None
                 
         return self
 
@@ -187,12 +190,12 @@ class BaseMLRegressor(object):
                         
         return y_hat
         
-    def score(self,X,y,sample_weight=None):
+    def score(self,X,y):
         
         # Check X and Y
         X, y = check_X_Y(X, y)
                         
-        score = self.estimator_cv.score(X=X,y=y,sample_weight=sample_weight)
+        score = self.estimator_cv.score(X=X,y=y)
                 
         return score
 
