@@ -2,11 +2,13 @@
 # Libraries
 #------------------------------------------------------------------------------
 # Standard
+import numpy as np
 from sklearn import (dummy,ensemble,gaussian_process,isotonic,kernel_ridge,
                      linear_model,neighbors,neural_network,svm,tree,)
 from itertools import compress
 
 # User
+from ..estimator import (boosting)
 from .sanity_check import check_estimator
 
 #------------------------------------------------------------------------------
@@ -68,10 +70,60 @@ def get_param_grid_from_estimator(estimator):
     The default parameter is *ALWAYS* the FIRST parameter listed, *UNLESS* the parameter is followed by a comment, e.g., "Default 100"
     Read the scikit-learn reference here: https://scikit-learn.org/stable/modules/classes.html# 
     """
+    #--------------------------------------------------------------------------
+    # from ..estimator.boosting
+    #--------------------------------------------------------------------------        
+    if isinstance(estimator, boosting.XGBRegressor):
+        param_grid = {
+            "n_estimators":[100,200,500],
+            "max_depth":[None,2,4,8,16],
+            "learning_rate":[1, 0.8, 0.5, 0.3, 0.1, 0.01],
+            "verbosity":0,
+            # "objective":'reg:squarederror', # Leads to RuntimeError: Cannot clone object XGBRegressor(...), as the constructor either does not set or modifies parameter objective
+            "booster":None,
+            "tree_method":None,
+            "gamma":[None, 0, 0.5],
+            "min_child_weight":[None,1,2,4,8],
+            "max_delta_step":None,
+            "subsample":[0.8,1,0.5],
+            "colsample_bytree":[None,1,2/3,1/3],
+            "colsample_bylevel":None,
+            "colsample_bynode":[0.8,1,0.5],
+            "reg_alpha":None,
+            "reg_lambda":[1e-05,0],
+            "scale_pos_weight":None,
+            "base_score":None,
+            "num_parallel_tree":None,
+            "monotone_constraints":None,
+            "interaction_constraints":None,
+            "importance_type":'gain',
+            }
+    
+    elif isinstance(estimator, boosting.LGBMegressor):
+        param_grid = {
+            "boosting_type":'gbdt',
+            "num_leaves":[31, 21, 41],
+            "max_depth":[-1,2,4,8,16],
+            "learning_rate":[0.1,0.8, 0.5, 0.3, 0.01],
+            "n_estimators":[100,200,500],
+            "subsample_for_bin":200000,
+            "objective":'regression',
+            "class_weight":None,
+            "min_split_gain":0.0,
+            "min_child_weight":0.001,
+            "min_child_samples":[20,4,8,16],
+            "subsample":[1.0,0.8,0.5],
+            "subsample_freq":0,
+            "colsample_bytree":[1.0,2/3,1/3],
+            "reg_alpha":[0.0,1e-05],
+            "reg_lambda":[0.0,1e-05],
+            "importance_type":'split'
+            }  
+    
     #--------------------------------------------------------------------------
     # from sklearn.dummy
     #--------------------------------------------------------------------------
-    if isinstance(estimator, dummy.DummyRegressor):
+    elif isinstance(estimator, dummy.DummyRegressor):
         param_grid = {
             "strategy":["mean","median","quantile","constant"],
             "constant":None,
@@ -97,7 +149,7 @@ def get_param_grid_from_estimator(estimator):
         param_grid = {
             "n_estimators":500,                                                # Default 100 
             "criterion":'squared_error',
-            "max_depth":[None,4,8,16],
+            "max_depth":[None,2,4,8,16],
             "min_samples_split":[2,4,8,16],
             "min_samples_leaf":[1,2,4,8],
             "min_weight_fraction_leaf":0.0,
@@ -267,47 +319,7 @@ def get_param_grid_from_estimator(estimator):
     #             "l1_ratio": [1/4, 1/2, 3/4, 1]
     #             }
     #     },
-    #     "XGBRegressor" : {
-    #         "model_params" : {
-    #             'booster' : 'gbtree',
-    #             'objective' : "reg:squarederror",
-    #             'verbosity' : 1,
-    #             'tree_method' : 'auto',
-    #             'validate_parameters' : 1
-    #             },
-    #         "tuning_params" : {
-    #             'learning_rate': [0.3, 0.1, 0.01, 0.5],
-    #             'gamma': [0, 0.5],
-    #             'max_depth': [6, 8, 4, 2],
-    #             'min_child_weight': [1, 4, 8],
-    #             'subsample': [1, 0.7],
-    #             'colsample_bytree': [1, 2/3, 1/3],
-    #             'n_estimators': [100, 200, 400]
-    #             }
-    #     },
-    #     "RandomForestRegressor" : {
-    #         "model_params" : {
-    #             "criterion":'mse',
-    #             "min_weight_fraction_leaf":0.0,
-    #             'min_impurity_decrease':0.0,
-    #             'min_impurity_split':None,
-    #             'bootstrap': True,
-    #             'oob_score':False,
-    #             'n_jobs':None,
-    #             'random_state':None,
-    #             'verbose':0,
-    #             'warm_start':False,
-    #             'ccp_alpha':0.0,
-    #             'max_samples':None
-    #             },
-    #         "tuning_params" : {
-    #             'n_estimators': 500,
-    #             'min_samples_split': [2,4,8,16],
-    #             'min_samples_leaf': [1,2,4,8],
-    #             'max_features': [1/4,1/3,1/2,2/3, 'sqrt','log2'],
-    #             'max_leaf_nodes': None,
-    #             'max_depth': [4,8,16,None]
-    #             }
+
     #     },
     #     "ExtraTreesRegressor" : {
     #         "model_params" : {
